@@ -37,6 +37,23 @@ class PolicyPlannerApis():
         except requests.exceptions.HTTPError as e:
             print("Exception occurred while creating policy planner ticket with workflow id '{0}'\n Exception : {1}".
                   format(workflow_id, e.response.text))
+
+    def siql_query_pp_ticket(self, siql_query: str, page_size: int) -> dict:
+        """
+        Making a SIQL Query to search for Policy Planner tickets
+        :param siql_query: SIQL query
+        :return: JSON of results
+        """
+        pp_tkt_url = self.parser.get('REST', 'siql_query_pp_tkt_api').format(self.host, self.domain_id)
+        parameters = {'q': siql_query, 'pageSize': page_size, 'domainid': self.domain_id }
+        try:
+            resp = requests.get(url=pp_tkt_url,
+                                 headers=self.headers, params=parameters, verify=self.verify_ssl)
+            print(">>>API Response Start>>>\n", resp.json(), "\n>>>API Response End>>>")
+            return resp.json()
+        except requests.exceptions.HTTPError as e:
+            print("Exception occurred while creating policy planner ticket with workflow id '{0}'\n Exception : {1}".
+                  format(workflow_id, e.response.text))
     
     def update_pp_ticket(self, ticket_id: str, request_body: dict) -> str:
         """
